var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import passport from 'passport';
import { Strategy as localStrategy } from 'passport-local';
import { encryptPwd, pwdIsValid } from '../model/model.mjs';
import { Strategy as JWTstrategy, ExtractJwt } from 'passport-jwt';
import { userDb } from '../db.mjs';
passport.use('signup', new localStrategy({
    usernameField: 'username',
    passwordField: 'password'
}, (username, password, done) => __awaiter(void 0, void 0, void 0, function* () {
    console.log("signup auth strategy has begun");
    try {
        const encryptedPwd = yield encryptPwd(password);
        const user = yield userDb("users").insert({ username: username, password: encryptedPwd }).returning(["username", "password"]);
        console.log(`user: ${user}`);
        return done(null, user);
    }
    catch (err) {
        console.error(err);
        done(err);
    }
})));
passport.use('login', new localStrategy({
    usernameField: "username",
    passwordField: "password",
    session: false
}, (email, password, done) => __awaiter(void 0, void 0, void 0, function* () {
    console.log("local strategy called");
    try {
        let returnedUser = yield userDb("users").select("username", "password").where({ username: email });
        const user = returnedUser[0];
        console.log(`user: ${user}`);
        if (!user || returnedUser.length === 0) {
            return done(null, false, { message: "user not found" });
        }
        const validate = yield pwdIsValid(password, user);
        console.log(`isValidPassword? ${validate}`);
        if (!validate) {
            return done(null, false, { message: "wrong password" });
        }
        return done(null, user, { message: "logged in successfully" });
    }
    catch (error) {
        return done(error);
    }
})));
passport.use(new JWTstrategy({
    secretOrKey: "TOP_SECRET",
    jwtFromRequest: ExtractJwt.fromAuthHeaderWithScheme('secret_token')
}, (token, done) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        return done(null, token.user);
    }
    catch (error) {
        done(error);
    }
})));
